@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::iata;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.008';
+our $VERSION = '1.009';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2026-01-26 - v1.009
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.057.
+
+=item *
+
 2026-01-12 - v1.008
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.056.
@@ -306,7 +312,7 @@ IRJ IRK IRM IRN IRO IRP IRS IRU IRZ ISA ISB ISC ISD ISE ISG ISH ISI ISJ
 ISK ISL ISM ISN ISO ISP ISQ ISS IST ISU ISW ITA ITB ITE ITH ITI ITJ ITK
 ITM ITN ITO ITP ITQ ITR ITU IUD IUE IUL IUM IUS IVA IVC IVG IVH IVI IVL
 IVO IVR IVW IWA IWD IWJ IWK IWO IWS IXA IXB IXC IXD IXE IXG IXH IXI IXJ
-IXK IXL IXM IXN IXP IXQ IXR IXS IXT IXU IXV IXW IXX IXY IXZ IYK IZA IZE
+IXK IXL IXM IXN IXP IXQ IXR IXS IXT IXU IXV IXW IXX IXY IXZ IYK IYO IZA IZE
 IZG IZO IZT JAA JAB JAC JAD JAE JAF JAG JAH JAI JAJ JAK JAL JAM JAN JAO
 JAP JAQ JAR JAS JAT JAU JAV JAX JBB JBC JBK JBP JBQ JBR JBS JBT JCA JCB
 JCC JCD JCE JCH JCI JCJ JCK JCM JCN JCO JCR JCS JCT JCU JCX JCY JDA JDE
