@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::icao;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.009';
+our $VERSION = '1.010';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2026-01-26 - v1.010
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.057.
+
+=item *
+
 2026-01-12 - v1.009
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.056.
@@ -198,7 +204,7 @@ FAVB FAVG FAVY FAWK FAWM FBKR FBMN FBOR FBPY FBSK FBSN FBSP FBSV FBSW
 FBTL FBTS FCBB FCBD FCBK FCBL FCBM FCBS FCBY FCBZ FCMM FCOB FCOE FCOG
 FCOI FCOK FCOM FCOO FCOS FCOT FCOU FCPA FCPD FCPP FDMB FDMS FDSK FEFF
 FEFG FEFI FEFL FEFM FEFN FEFO FEFR FEFS FEFT FEFY FEGZ FGBT FGSL FHAW
-FIMP FIMR FJDG FKAN FKKB FKKC FKKD FKKF FKKI FKKL FKKM FKKN FKKR FKKU
+FIMP FIMR FJDG FKAN FKKB FKKC FKKD FKKF FKKH FKKI FKKL FKKM FKKN FKKR FKKU
 FKKV FKKY FKYS FLBA FLCP FLJK FLKE FLKS FLKW FLKY FLLI FLLS FLMA FLMF
 FLMG FLND FLRZ FLSN FLSO FLSS FLSW FLZB FMCH FMCI FMCN FMCV FMCZ FMEE
 FMEP FMME FMMG FMMH FMMI FMMK FMML FMMN FMMO FMMR FMMS FMMT FMMU FMMV
@@ -580,7 +586,7 @@ UTAN UTAT UTAV UTDD UTDK UTDL UTKA UTKF UTKN UTNN UTNU UTSA UTSB UTSH
 UTSL UTSN UTSS UTST UTTT UTTZ UUBB UUBD UUBI UUBK UUBP UUBS UUDD UUDL
 UUEE UUEM UUMU UUOB UUOK UUOL UUOO UUOT UUWW UUYW UUYY UWGG UWKB UWKD
 UWKE UWKJ UWKS UWLL UWLW UWOO UWOR UWPP UWPS UWSB UWSS UWUB UWUU UWWW
-UZNM UZSH UZTZ VA1P VAAH VAAK VAAM VAAU VABB VABI VABJ VABM VABO VABP
+UZNM UZSH UZSR UZTZ VA1P VAAH VAAK VAAM VAAU VABB VABI VABJ VABM VABO VABP
 VABV VADN VAGN VAGO VAHB VAID VAJB VAJM VAKE VAKJ VAKP VAKS VAND VANM
 VANP VANR VAPO VAPR VARG VARK VARP VASL VASU VAUD VCBI VCCA VCCB VCCC
 VCCG VCCJ VCCK VCCT VCCW VCRI VDBG VDDS VDKC VDKT VDPP VDSR VDST VDSV
