@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::oulipo;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA     = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 use utf8;
 
 =encoding utf-8
@@ -38,7 +38,7 @@ Noël ARNAUD (1919-2003), founding member.
 
 =item *
 
-Michèle AUDIN (1954-), joined in 2009.
+Michèle AUDIN (1954-2025), joined in 2009.
 
 =item *
 
@@ -66,7 +66,7 @@ André BLAVIER (1922-2001), foreign correspondent.
 
 =item *
 
-Paul BRAFFORT (1923-), joined in 1961.
+Paul BRAFFORT (1923-2018), joined in 1961.
 
 =item *
 
@@ -82,7 +82,7 @@ Bernard CERQUIGLINI (1947-), joined in 1995.
 
 =item *
 
-Ross CHAMBERS (1932-), joined in 1961.
+Ross CHAMBERS (1932-2017), joined in 1961.
 
 =item *
 
@@ -90,11 +90,15 @@ Stanley CHAPMAN (1925-2009), joined in 1961.
 
 =item *
 
+Samuel DESHAYES (1978-), joined in 2026.
+
+=item *
+
 Marcel DUCHAMP (1887-1968), joined in 1962.
 
 =item *
 
-Jacques DUCHATEAU (1929-), founding member.
+Jacques DUCHATEAU (1929-2017), founding member.
 
 =item *
 
@@ -114,7 +118,7 @@ Anne F. GARRÉTA (1962-), joined in 2000.
 
 =item *
 
-Michelle GRANGAUD (1941-), joined in 1995.
+Michelle GRANGAUD (1941-2022), joined in 1995.
 
 =item *
 
@@ -146,11 +150,15 @@ Daniel LEVIN BECKER (1984-), joined in 2009.
 
 =item *
 
+Guillaume MARIE (1979-), joined in 2026.
+
+=item *
+
 Pablo MARTÍN SÁNCHEZ (1977-), joined in 2014.
 
 =item *
 
-Harry MATHEWS (1930-), joined in 1973.
+Harry MATHEWS (1930-2017), joined in 1973.
 
 =item *
 
@@ -158,7 +166,7 @@ Michèle MÉTAIL (1950-), joined in 1975.
 
 =item *
 
-Ian MONK (1960-), joined in 1998.
+Ian MONK (1960-2025), joined in 1998.
 
 =item *
 
@@ -178,11 +186,15 @@ Jean QUEVAL (1913-1990), founding member.
 
 =item *
 
-Pierre ROSENSTIEHL (1933-), joined in 1992.
+Louise ROSE (1996-), joined in 2026.
 
 =item *
 
-Jacques ROUBAUD (1932-), joined in 1966.
+Pierre ROSENSTIEHL (1933-2020), joined in 1992.
+
+=item *
+
+Jacques ROUBAUD (1932-2024), joined in 1966.
 
 =item *
 
@@ -207,6 +219,14 @@ the first Oulipo web site, back in 1995.
 
 =item *
 
+2026-01-26 - v1.004
+
+Updated with three new members,
+and the date of death of recently passed members
+in Acme-MetaSyntactic-Themes version 1.057.
+
+=item *
+
 2014-09-15 - v1.003
 
 Updated with two new members,
