@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pm_groups;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.031';
+our $VERSION = '1.032';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -38,6 +38,12 @@ Philippe Bruhat (BooK)
 
 =item *
 
+2026-01-12 - v1.032
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.056.
+
+=item *
+
 2021-04-30 - v1.031
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.055.
@@ -330,210 +336,25 @@ L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
 
 __DATA__
 # names
-Albany_pm
-Albuquerque_pm
-Atlanta_pm
 Austin_pm
-Baltimore_pm
+Berlin_pm
+Birmingham_pm
 Boston_pm
-Champaign_Urbana_pm
-Chicago_pm
-Cincinnati_pm
-Cleveland_pm
-Columbus_pm
-DFW_pm
+Dahut_pm
 DC_pm
-HudsonValley_pm
 Houston_pm
-KansasCity_pm
-LasVegas_pm
-Milwaukee_pm
-Minneapolis_pm
-Montreal_pm
-OrangeCounty_pm
-Ottawa_pm
+Kichij_ji_pm
+London_pm
+Los_Angeles_pm
+Okinawa_pm
+Oslo_pm
+Paris_pm
 Philadelphia_pm
-Phoenix_pm
-PDX_pm
-Raleigh_pm
+Purdue_pm
 SanDiego_pm
 SanFrancisco_pm
-Seattle_pm
+Sh_nan_pm
 Sonoma_pm
-StLouis_pm
-Tallahassee_pm
-Toronto_pm
-Vancouver_pm
-Curitiba_pm
-Amsterdam_pm
-Braga_pm
-Bratislava_pm
-Edinburgh_pm
-Glasgow_pm
-Helsinki_pm
-Copenhagen_pm
-Leipzig_pm
-Lisbon_pm
-London_pm
-Munich_pm
-Paris_pm
-Porto_pm
-Roma_pm
-Southampton_pm
-SPb_pm
-Torino_pm
-Vienna_pm
-Zagreb_pm
-Brisbane_pm
-Melbourne_pm
-Perth_pm
-Singapore_pm
 Sydney_pm
-Bandung_pm
-Beijing_pm
-Delhi_pm
-HongKong_pm
-Kyoto_pm
-Pune_pm
-Shanghai_pm
-Israel_pm
-Rehovot_pm
-CapeTown_pm
-Guimaraes_pm
-SiliconValley_pm
-Tempe_pm
-Oslo_pm
-Madrid_pm
-Hyderabad_pm
-Budapest_pm
-Purdue_pm
-Frankfurt_pm
-Milan_pm
-Coimbra_pm
-Kansai_pm
-Madras_pm
-Granada_pm
-Seneca_pm
-Ulm_pm
-AtlanticCity_pm
-Los_Angeles_pm
-Athens_pm
-Qatar_pm
-Chisinau_pm
-Birmingham_pm
-Colombo_pm
-Toulouse_pm
-Niederrhein_pm
-Barcelona_pm
-Santa_Fe_Los_Alamos_pm
-Victoria_pm
-Wellington_pm
-Marseille_pm
-Timisoara_pm
-Salem_pm
-Prague_pm
-Bend_pm
-Berlin_pm
-Bergen_pm
-SaltLake_pm
-Nordest_pm
-CaFe_pm
-Tucson_pm
-Devon_and_Cornwall_pm
-Lyon_pm
-Basel_pm
-Bruxelles_pm
-CAMEL_pm
-Belgrade_pm
-China_pm
-Bucharest_pm
-Mumbai_pm
-Kw_pm
-Dresden_pm
-Cologne_pm
-Hamburg_pm
-Guatemala_pm
-Helsingborg_pm
-Vlaanderen_pm
-Saarland_pm
-Shibuya_pm
-Pisa_pm
-Arnhem_pm
-Stuttgart_pm
-Dahut_pm
-Roederbergweg_pm
-Bielefeld_pm
-Nottingham_pm
-Jerusalem_pm
-Ankara_pm
-Italia_pm
-Geneva_pm
-Paderborn_pm
-Campinas_pm
-BH_pm
-Argentina_pm
-Groningen_pm
-Innsbruck_pm
-Santiago_pm
-Erlangen_pm
-MiltonKeynes_pm
-Darmstadt_pm
-Ruhr_pm
-Poznan_pm
-Kaiserslautern_pm
-Coimbatore_pm
-Sophia_pm
-Warszawa_pm
-Hannover_pm
-Szczecin_pm
-Ithaca_pm
-Tomar_pm
-Fukuoka_pm
-Vladivostok_pm
-RostovOnDon_pm
-Minsk_pm
-Odessa_pm
-Yokohama_pm
-Krasnodar_pm
-Fredericton_pm
-Northwestengland_pm
-Quito_pm
-Kushiro_pm
-Lima_pm
-Advent_pm
-Madurai_pm
-Hokkaido_pm
-Linz_pm
-Nagoya_pm
-Kamakura_pm
-Kathmandu_pm
-TelAviv_pm
-Makati_pm
-Bordeaux_pm
-Petropolis_pm
-Brno_pm
-Logan_pm
-SouthernOregon_pm
-Plzen_pm
-Sendai_pm
-Kerman_pm
-Cluj_pm
-Niigata_pm
-Hardware_pm
-Duesseldorf_pm
-Augsburg_pm
-CorpusChristi_pm
-Cochin_pm
-AmsterdamX_pm
-UKCoordinators_pm
-NewTaipeiCity_pm
-Gdansk_pm
-Chico_pm
-Gotanda_pm
-Fleet_pm
-Niceville_pm
-Okinawa_pm
-Ryazan_pm
-BlairCountyPA_pm
-Charlotte_pm
-Madison_pm
+Toronto_pm
+Vienna_pm
